/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qcalendarwidget.sip"
#include <qcalendarwidget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcalendar.sip"
#include <qcalendar.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 319 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 232 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCalendarWidget.cpp"


class sipQCalendarWidget : public ::QCalendarWidget
{
public:
    sipQCalendarWidget(::QWidget*);
    virtual ~sipQCalendarWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void paintCell(::QPainter*, const ::QRect&, ::QDate) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCalendarWidget(const sipQCalendarWidget &);
    sipQCalendarWidget &operator = (const sipQCalendarWidget &);

    char sipPyMethods[47];
};

sipQCalendarWidget::sipQCalendarWidget(::QWidget*a0): ::QCalendarWidget(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCalendarWidget::~sipQCalendarWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCalendarWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QCalendarWidget);

    return ::QCalendarWidget::metaObject();
}

int sipQCalendarWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCalendarWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QCalendarWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCalendarWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QCalendarWidget, _clname, &sipCpp) ? sipCpp : ::QCalendarWidget::qt_metacast(_clname));
}

void sipQCalendarWidget::paintCell(::QPainter*a0, const ::QRect& a1, ::QDate a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintCell);

    if (!sipMeth)
    {
        ::QCalendarWidget::paintCell(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, ::QDate);

    sipVH_QtWidgets_92(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQCalendarWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCalendarWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCalendarWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCalendarWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCalendarWidget::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCalendarWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCalendarWidget::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQCalendarWidget::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QCalendarWidget::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQCalendarWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QCalendarWidget::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQCalendarWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QCalendarWidget::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCalendarWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QCalendarWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQCalendarWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QCalendarWidget::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQCalendarWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QCalendarWidget::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQCalendarWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QCalendarWidget::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCalendarWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QCalendarWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQCalendarWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QCalendarWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCalendarWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QCalendarWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCalendarWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QCalendarWidget::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQCalendarWidget::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QCalendarWidget::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQCalendarWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QCalendarWidget::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCalendarWidget::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QCalendarWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCalendarWidget_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QCalendarWidget_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QCalendarWidget::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_sizeHint, doc_QCalendarWidget_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QCalendarWidget_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QCalendarWidget::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_minimumSizeHint, doc_QCalendarWidget_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_selectedDate, "selectedDate(self) -> QDate");

extern "C" {static PyObject *meth_QCalendarWidget_selectedDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_selectedDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->selectedDate());

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_selectedDate, doc_QCalendarWidget_selectedDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_yearShown, "yearShown(self) -> int");

extern "C" {static PyObject *meth_QCalendarWidget_yearShown(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_yearShown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->yearShown();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_yearShown, doc_QCalendarWidget_yearShown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_monthShown, "monthShown(self) -> int");

extern "C" {static PyObject *meth_QCalendarWidget_monthShown(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_monthShown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->monthShown();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_monthShown, doc_QCalendarWidget_monthShown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_minimumDate, "minimumDate(self) -> QDate");

extern "C" {static PyObject *meth_QCalendarWidget_minimumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_minimumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->minimumDate());

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_minimumDate, doc_QCalendarWidget_minimumDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setMinimumDate, "setMinimumDate(self, date: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_setMinimumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setMinimumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State))
        {
            sipCpp->setMinimumDate(*a0);
            sipReleaseType(a0, sipType_QDate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setMinimumDate, doc_QCalendarWidget_setMinimumDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_maximumDate, "maximumDate(self) -> QDate");

extern "C" {static PyObject *meth_QCalendarWidget_maximumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_maximumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->maximumDate());

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_maximumDate, doc_QCalendarWidget_maximumDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setMaximumDate, "setMaximumDate(self, date: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_setMaximumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setMaximumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State))
        {
            sipCpp->setMaximumDate(*a0);
            sipReleaseType(a0, sipType_QDate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setMaximumDate, doc_QCalendarWidget_setMaximumDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_firstDayOfWeek, "firstDayOfWeek(self) -> Qt.DayOfWeek");

extern "C" {static PyObject *meth_QCalendarWidget_firstDayOfWeek(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_firstDayOfWeek(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::Qt::DayOfWeek sipRes;

            sipRes = sipCpp->firstDayOfWeek();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_DayOfWeek);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_firstDayOfWeek, doc_QCalendarWidget_firstDayOfWeek);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setFirstDayOfWeek, "setFirstDayOfWeek(self, dayOfWeek: Qt.DayOfWeek)");

extern "C" {static PyObject *meth_QCalendarWidget_setFirstDayOfWeek(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setFirstDayOfWeek(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::DayOfWeek a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_Qt_DayOfWeek, &a0))
        {
            sipCpp->setFirstDayOfWeek(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setFirstDayOfWeek, doc_QCalendarWidget_setFirstDayOfWeek);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_isGridVisible, "isGridVisible(self) -> bool");

extern "C" {static PyObject *meth_QCalendarWidget_isGridVisible(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_isGridVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isGridVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_isGridVisible, doc_QCalendarWidget_isGridVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setGridVisible, "setGridVisible(self, show: bool)");

extern "C" {static PyObject *meth_QCalendarWidget_setGridVisible(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setGridVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QCalendarWidget, &sipCpp, &a0))
        {
            sipCpp->setGridVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setGridVisible, doc_QCalendarWidget_setGridVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_selectionMode, "selectionMode(self) -> QCalendarWidget.SelectionMode");

extern "C" {static PyObject *meth_QCalendarWidget_selectionMode(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_selectionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QCalendarWidget::SelectionMode sipRes;

            sipRes = sipCpp->selectionMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCalendarWidget_SelectionMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_selectionMode, doc_QCalendarWidget_selectionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setSelectionMode, "setSelectionMode(self, mode: QCalendarWidget.SelectionMode)");

extern "C" {static PyObject *meth_QCalendarWidget_setSelectionMode(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setSelectionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget::SelectionMode a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QCalendarWidget_SelectionMode, &a0))
        {
            sipCpp->setSelectionMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setSelectionMode, doc_QCalendarWidget_setSelectionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_horizontalHeaderFormat, "horizontalHeaderFormat(self) -> QCalendarWidget.HorizontalHeaderFormat");

extern "C" {static PyObject *meth_QCalendarWidget_horizontalHeaderFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_horizontalHeaderFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QCalendarWidget::HorizontalHeaderFormat sipRes;

            sipRes = sipCpp->horizontalHeaderFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCalendarWidget_HorizontalHeaderFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_horizontalHeaderFormat, doc_QCalendarWidget_horizontalHeaderFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setHorizontalHeaderFormat, "setHorizontalHeaderFormat(self, format: QCalendarWidget.HorizontalHeaderFormat)");

extern "C" {static PyObject *meth_QCalendarWidget_setHorizontalHeaderFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setHorizontalHeaderFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget::HorizontalHeaderFormat a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QCalendarWidget_HorizontalHeaderFormat, &a0))
        {
            sipCpp->setHorizontalHeaderFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setHorizontalHeaderFormat, doc_QCalendarWidget_setHorizontalHeaderFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_verticalHeaderFormat, "verticalHeaderFormat(self) -> QCalendarWidget.VerticalHeaderFormat");

extern "C" {static PyObject *meth_QCalendarWidget_verticalHeaderFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_verticalHeaderFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QCalendarWidget::VerticalHeaderFormat sipRes;

            sipRes = sipCpp->verticalHeaderFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCalendarWidget_VerticalHeaderFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_verticalHeaderFormat, doc_QCalendarWidget_verticalHeaderFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setVerticalHeaderFormat, "setVerticalHeaderFormat(self, format: QCalendarWidget.VerticalHeaderFormat)");

extern "C" {static PyObject *meth_QCalendarWidget_setVerticalHeaderFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setVerticalHeaderFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget::VerticalHeaderFormat a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QCalendarWidget_VerticalHeaderFormat, &a0))
        {
            sipCpp->setVerticalHeaderFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setVerticalHeaderFormat, doc_QCalendarWidget_setVerticalHeaderFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_headerTextFormat, "headerTextFormat(self) -> QTextCharFormat");

extern "C" {static PyObject *meth_QCalendarWidget_headerTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_headerTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QTextCharFormat*sipRes;

            sipRes = new ::QTextCharFormat(sipCpp->headerTextFormat());

            return sipConvertFromNewType(sipRes, sipType_QTextCharFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_headerTextFormat, doc_QCalendarWidget_headerTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setHeaderTextFormat, "setHeaderTextFormat(self, format: QTextCharFormat)");

extern "C" {static PyObject *meth_QCalendarWidget_setHeaderTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setHeaderTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextCharFormat* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QTextCharFormat, &a0))
        {
            sipCpp->setHeaderTextFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setHeaderTextFormat, doc_QCalendarWidget_setHeaderTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_weekdayTextFormat, "weekdayTextFormat(self, dayOfWeek: Qt.DayOfWeek) -> QTextCharFormat");

extern "C" {static PyObject *meth_QCalendarWidget_weekdayTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_weekdayTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::DayOfWeek a0;
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_Qt_DayOfWeek, &a0))
        {
            ::QTextCharFormat*sipRes;

            sipRes = new ::QTextCharFormat(sipCpp->weekdayTextFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QTextCharFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_weekdayTextFormat, doc_QCalendarWidget_weekdayTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setWeekdayTextFormat, "setWeekdayTextFormat(self, dayOfWeek: Qt.DayOfWeek, format: QTextCharFormat)");

extern "C" {static PyObject *meth_QCalendarWidget_setWeekdayTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setWeekdayTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::DayOfWeek a0;
        const ::QTextCharFormat* a1;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_Qt_DayOfWeek, &a0, sipType_QTextCharFormat, &a1))
        {
            sipCpp->setWeekdayTextFormat(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setWeekdayTextFormat, doc_QCalendarWidget_setWeekdayTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_dateTextFormat, "dateTextFormat(self) -> dict[QDate, QTextCharFormat]\n"
"dateTextFormat(self, date: QDate|datetime.date) -> QTextCharFormat");

extern "C" {static PyObject *meth_QCalendarWidget_dateTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_dateTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            QMap< ::QDate, ::QTextCharFormat>*sipRes;

            sipRes = new QMap< ::QDate, ::QTextCharFormat>(sipCpp->dateTextFormat());

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QDate_0100QTextCharFormat, SIP_NULLPTR);
        }
    }

    {
        ::QDate* a0;
        int a0State = 0;
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State))
        {
            ::QTextCharFormat*sipRes;

            sipRes = new ::QTextCharFormat(sipCpp->dateTextFormat(*a0));
            sipReleaseType(a0, sipType_QDate, a0State);

            return sipConvertFromNewType(sipRes, sipType_QTextCharFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_dateTextFormat, doc_QCalendarWidget_dateTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setDateTextFormat, "setDateTextFormat(self, date: QDate|datetime.date, format: QTextCharFormat)");

extern "C" {static PyObject *meth_QCalendarWidget_setDateTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setDateTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        const ::QTextCharFormat* a1;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QTextCharFormat, &a1))
        {
            sipCpp->setDateTextFormat(*a0, *a1);
            sipReleaseType(a0, sipType_QDate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setDateTextFormat, doc_QCalendarWidget_setDateTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_updateCell, "updateCell(self, date: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_updateCell(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_updateCell(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State))
        {
            sipCpp->updateCell(*a0);
            sipReleaseType(a0, sipType_QDate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_updateCell, doc_QCalendarWidget_updateCell);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_updateCells, "updateCells(self)");

extern "C" {static PyObject *meth_QCalendarWidget_updateCells(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_updateCells(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->updateCells();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_updateCells, doc_QCalendarWidget_updateCells);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_event, "event(self, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QCalendarWidget_event(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCalendarWidget::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_event, doc_QCalendarWidget_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_eventFilter, "eventFilter(self, watched: QObject|None, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QCalendarWidget_eventFilter(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_eventFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QEvent* a1;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCalendarWidget::eventFilter(a0, a1) : sipCpp->eventFilter(a0, a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_eventFilter, doc_QCalendarWidget_eventFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_mousePressEvent, "mousePressEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QCalendarWidget_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCalendarWidget::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_mousePressEvent, doc_QCalendarWidget_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_resizeEvent, "resizeEvent(self, event: QResizeEvent|None)");

extern "C" {static PyObject *meth_QCalendarWidget_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCalendarWidget::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_resizeEvent, doc_QCalendarWidget_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_keyPressEvent, "keyPressEvent(self, event: QKeyEvent|None)");

extern "C" {static PyObject *meth_QCalendarWidget_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCalendarWidget::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_keyPressEvent, doc_QCalendarWidget_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_paintCell, "paintCell(self, painter: QPainter|None, rect: QRect, date: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_paintCell(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_paintCell(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCalendarWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QRect* a1;
        ::QDate* a2;
        int a2State = 0;
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J9J1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, sipType_QDate, &a2, &a2State))
        {
            (sipSelfWasArg ? sipCpp->::QCalendarWidget::paintCell(a0, *a1, *a2) : sipCpp->paintCell(a0, *a1, *a2));
            sipReleaseType(a2, sipType_QDate, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_paintCell, doc_QCalendarWidget_paintCell);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setCurrentPage, "setCurrentPage(self, year: int, month: int)");

extern "C" {static PyObject *meth_QCalendarWidget_setCurrentPage(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setCurrentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QCalendarWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setCurrentPage(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setCurrentPage, doc_QCalendarWidget_setCurrentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setDateRange, "setDateRange(self, min: QDate|datetime.date, max: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_setDateRange(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setDateRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QDate* a1;
        int a1State = 0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QDate, &a1, &a1State))
        {
            sipCpp->setDateRange(*a0, *a1);
            sipReleaseType(a0, sipType_QDate, a0State);
            sipReleaseType(a1, sipType_QDate, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setDateRange, doc_QCalendarWidget_setDateRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setSelectedDate, "setSelectedDate(self, date: QDate|datetime.date)");

extern "C" {static PyObject *meth_QCalendarWidget_setSelectedDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setSelectedDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QDate, &a0, &a0State))
        {
            sipCpp->setSelectedDate(*a0);
            sipReleaseType(a0, sipType_QDate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setSelectedDate, doc_QCalendarWidget_setSelectedDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showNextMonth, "showNextMonth(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showNextMonth(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showNextMonth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showNextMonth();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showNextMonth, doc_QCalendarWidget_showNextMonth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showNextYear, "showNextYear(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showNextYear(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showNextYear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showNextYear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showNextYear, doc_QCalendarWidget_showNextYear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showPreviousMonth, "showPreviousMonth(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showPreviousMonth(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showPreviousMonth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showPreviousMonth();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showPreviousMonth, doc_QCalendarWidget_showPreviousMonth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showPreviousYear, "showPreviousYear(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showPreviousYear(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showPreviousYear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showPreviousYear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showPreviousYear, doc_QCalendarWidget_showPreviousYear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showSelectedDate, "showSelectedDate(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showSelectedDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showSelectedDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showSelectedDate();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showSelectedDate, doc_QCalendarWidget_showSelectedDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_showToday, "showToday(self)");

extern "C" {static PyObject *meth_QCalendarWidget_showToday(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_showToday(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->showToday();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_showToday, doc_QCalendarWidget_showToday);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_isNavigationBarVisible, "isNavigationBarVisible(self) -> bool");

extern "C" {static PyObject *meth_QCalendarWidget_isNavigationBarVisible(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_isNavigationBarVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNavigationBarVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_isNavigationBarVisible, doc_QCalendarWidget_isNavigationBarVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_isDateEditEnabled, "isDateEditEnabled(self) -> bool");

extern "C" {static PyObject *meth_QCalendarWidget_isDateEditEnabled(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_isDateEditEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDateEditEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_isDateEditEnabled, doc_QCalendarWidget_isDateEditEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setDateEditEnabled, "setDateEditEnabled(self, enable: bool)");

extern "C" {static PyObject *meth_QCalendarWidget_setDateEditEnabled(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setDateEditEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QCalendarWidget, &sipCpp, &a0))
        {
            sipCpp->setDateEditEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setDateEditEnabled, doc_QCalendarWidget_setDateEditEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_dateEditAcceptDelay, "dateEditAcceptDelay(self) -> int");

extern "C" {static PyObject *meth_QCalendarWidget_dateEditAcceptDelay(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_dateEditAcceptDelay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->dateEditAcceptDelay();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_dateEditAcceptDelay, doc_QCalendarWidget_dateEditAcceptDelay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setDateEditAcceptDelay, "setDateEditAcceptDelay(self, delay: int)");

extern "C" {static PyObject *meth_QCalendarWidget_setDateEditAcceptDelay(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setDateEditAcceptDelay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QCalendarWidget, &sipCpp, &a0))
        {
            sipCpp->setDateEditAcceptDelay(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setDateEditAcceptDelay, doc_QCalendarWidget_setDateEditAcceptDelay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setNavigationBarVisible, "setNavigationBarVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QCalendarWidget_setNavigationBarVisible(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setNavigationBarVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QCalendarWidget, &sipCpp, &a0))
        {
            sipCpp->setNavigationBarVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setNavigationBarVisible, doc_QCalendarWidget_setNavigationBarVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_calendar, "calendar(self) -> QCalendar");

extern "C" {static PyObject *meth_QCalendarWidget_calendar(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_calendar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            ::QCalendar*sipRes;

            sipRes = new ::QCalendar(sipCpp->calendar());

            return sipConvertFromNewType(sipRes, sipType_QCalendar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_calendar, doc_QCalendarWidget_calendar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_setCalendar, "setCalendar(self, calendar: QCalendar)");

extern "C" {static PyObject *meth_QCalendarWidget_setCalendar(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_setCalendar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendar* a0;
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCalendarWidget, &sipCpp, sipType_QCalendar, &a0))
        {
            sipCpp->setCalendar(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_setCalendar, doc_QCalendarWidget_setCalendar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_clearMinimumDate, "clearMinimumDate(self)");

extern "C" {static PyObject *meth_QCalendarWidget_clearMinimumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_clearMinimumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->clearMinimumDate();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_clearMinimumDate, doc_QCalendarWidget_clearMinimumDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarWidget_clearMaximumDate, "clearMaximumDate(self)");

extern "C" {static PyObject *meth_QCalendarWidget_clearMaximumDate(PyObject *, PyObject *);}
static PyObject *meth_QCalendarWidget_clearMaximumDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarWidget, &sipCpp))
        {
            sipCpp->clearMaximumDate();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarWidget, sipName_clearMaximumDate, doc_QCalendarWidget_clearMaximumDate);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCalendarWidget(void *, const sipTypeDef *);}
static void *cast_QCalendarWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCalendarWidget *sipCpp = reinterpret_cast< ::QCalendarWidget *>(sipCppV);

    if (targetType == sipType_QCalendarWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCalendarWidget(void *, int);}
static void release_QCalendarWidget(void *sipCppV, int)
{
    ::QCalendarWidget *sipCpp = reinterpret_cast< ::QCalendarWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QCalendarWidget(Py_ssize_t);}
static void *array_QCalendarWidget(Py_ssize_t sipNrElem)
{
    return new ::QCalendarWidget[sipNrElem];
}


extern "C" {static void array_delete_QCalendarWidget(void *);}
static void array_delete_QCalendarWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCalendarWidget *>(sipCpp);
}


extern "C" {static void dealloc_QCalendarWidget(sipSimpleWrapper *);}
static void dealloc_QCalendarWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCalendarWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCalendarWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCalendarWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCalendarWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCalendarWidget *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQCalendarWidget(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCalendarWidget[] = {{444, 255, 1}};


static PyMethodDef methods_QCalendarWidget[] = {
    {sipName_calendar, meth_QCalendarWidget_calendar, METH_VARARGS, doc_QCalendarWidget_calendar},
    {sipName_clearMaximumDate, meth_QCalendarWidget_clearMaximumDate, METH_VARARGS, doc_QCalendarWidget_clearMaximumDate},
    {sipName_clearMinimumDate, meth_QCalendarWidget_clearMinimumDate, METH_VARARGS, doc_QCalendarWidget_clearMinimumDate},
    {sipName_dateEditAcceptDelay, meth_QCalendarWidget_dateEditAcceptDelay, METH_VARARGS, doc_QCalendarWidget_dateEditAcceptDelay},
    {sipName_dateTextFormat, meth_QCalendarWidget_dateTextFormat, METH_VARARGS, doc_QCalendarWidget_dateTextFormat},
    {sipName_event, meth_QCalendarWidget_event, METH_VARARGS, doc_QCalendarWidget_event},
    {sipName_eventFilter, meth_QCalendarWidget_eventFilter, METH_VARARGS, doc_QCalendarWidget_eventFilter},
    {sipName_firstDayOfWeek, meth_QCalendarWidget_firstDayOfWeek, METH_VARARGS, doc_QCalendarWidget_firstDayOfWeek},
    {sipName_headerTextFormat, meth_QCalendarWidget_headerTextFormat, METH_VARARGS, doc_QCalendarWidget_headerTextFormat},
    {sipName_horizontalHeaderFormat, meth_QCalendarWidget_horizontalHeaderFormat, METH_VARARGS, doc_QCalendarWidget_horizontalHeaderFormat},
    {sipName_isDateEditEnabled, meth_QCalendarWidget_isDateEditEnabled, METH_VARARGS, doc_QCalendarWidget_isDateEditEnabled},
    {sipName_isGridVisible, meth_QCalendarWidget_isGridVisible, METH_VARARGS, doc_QCalendarWidget_isGridVisible},
    {sipName_isNavigationBarVisible, meth_QCalendarWidget_isNavigationBarVisible, METH_VARARGS, doc_QCalendarWidget_isNavigationBarVisible},
    {sipName_keyPressEvent, meth_QCalendarWidget_keyPressEvent, METH_VARARGS, doc_QCalendarWidget_keyPressEvent},
    {sipName_maximumDate, meth_QCalendarWidget_maximumDate, METH_VARARGS, doc_QCalendarWidget_maximumDate},
    {sipName_minimumDate, meth_QCalendarWidget_minimumDate, METH_VARARGS, doc_QCalendarWidget_minimumDate},
    {sipName_minimumSizeHint, meth_QCalendarWidget_minimumSizeHint, METH_VARARGS, doc_QCalendarWidget_minimumSizeHint},
    {sipName_monthShown, meth_QCalendarWidget_monthShown, METH_VARARGS, doc_QCalendarWidget_monthShown},
    {sipName_mousePressEvent, meth_QCalendarWidget_mousePressEvent, METH_VARARGS, doc_QCalendarWidget_mousePressEvent},
    {sipName_paintCell, meth_QCalendarWidget_paintCell, METH_VARARGS, doc_QCalendarWidget_paintCell},
    {sipName_resizeEvent, meth_QCalendarWidget_resizeEvent, METH_VARARGS, doc_QCalendarWidget_resizeEvent},
    {sipName_selectedDate, meth_QCalendarWidget_selectedDate, METH_VARARGS, doc_QCalendarWidget_selectedDate},
    {sipName_selectionMode, meth_QCalendarWidget_selectionMode, METH_VARARGS, doc_QCalendarWidget_selectionMode},
    {sipName_setCalendar, meth_QCalendarWidget_setCalendar, METH_VARARGS, doc_QCalendarWidget_setCalendar},
    {sipName_setCurrentPage, meth_QCalendarWidget_setCurrentPage, METH_VARARGS, doc_QCalendarWidget_setCurrentPage},
    {sipName_setDateEditAcceptDelay, meth_QCalendarWidget_setDateEditAcceptDelay, METH_VARARGS, doc_QCalendarWidget_setDateEditAcceptDelay},
    {sipName_setDateEditEnabled, meth_QCalendarWidget_setDateEditEnabled, METH_VARARGS, doc_QCalendarWidget_setDateEditEnabled},
    {sipName_setDateRange, meth_QCalendarWidget_setDateRange, METH_VARARGS, doc_QCalendarWidget_setDateRange},
    {sipName_setDateTextFormat, meth_QCalendarWidget_setDateTextFormat, METH_VARARGS, doc_QCalendarWidget_setDateTextFormat},
    {sipName_setFirstDayOfWeek, meth_QCalendarWidget_setFirstDayOfWeek, METH_VARARGS, doc_QCalendarWidget_setFirstDayOfWeek},
    {sipName_setGridVisible, meth_QCalendarWidget_setGridVisible, METH_VARARGS, doc_QCalendarWidget_setGridVisible},
    {sipName_setHeaderTextFormat, meth_QCalendarWidget_setHeaderTextFormat, METH_VARARGS, doc_QCalendarWidget_setHeaderTextFormat},
    {sipName_setHorizontalHeaderFormat, meth_QCalendarWidget_setHorizontalHeaderFormat, METH_VARARGS, doc_QCalendarWidget_setHorizontalHeaderFormat},
    {sipName_setMaximumDate, meth_QCalendarWidget_setMaximumDate, METH_VARARGS, doc_QCalendarWidget_setMaximumDate},
    {sipName_setMinimumDate, meth_QCalendarWidget_setMinimumDate, METH_VARARGS, doc_QCalendarWidget_setMinimumDate},
    {sipName_setNavigationBarVisible, meth_QCalendarWidget_setNavigationBarVisible, METH_VARARGS, doc_QCalendarWidget_setNavigationBarVisible},
    {sipName_setSelectedDate, meth_QCalendarWidget_setSelectedDate, METH_VARARGS, doc_QCalendarWidget_setSelectedDate},
    {sipName_setSelectionMode, meth_QCalendarWidget_setSelectionMode, METH_VARARGS, doc_QCalendarWidget_setSelectionMode},
    {sipName_setVerticalHeaderFormat, meth_QCalendarWidget_setVerticalHeaderFormat, METH_VARARGS, doc_QCalendarWidget_setVerticalHeaderFormat},
    {sipName_setWeekdayTextFormat, meth_QCalendarWidget_setWeekdayTextFormat, METH_VARARGS, doc_QCalendarWidget_setWeekdayTextFormat},
    {sipName_showNextMonth, meth_QCalendarWidget_showNextMonth, METH_VARARGS, doc_QCalendarWidget_showNextMonth},
    {sipName_showNextYear, meth_QCalendarWidget_showNextYear, METH_VARARGS, doc_QCalendarWidget_showNextYear},
    {sipName_showPreviousMonth, meth_QCalendarWidget_showPreviousMonth, METH_VARARGS, doc_QCalendarWidget_showPreviousMonth},
    {sipName_showPreviousYear, meth_QCalendarWidget_showPreviousYear, METH_VARARGS, doc_QCalendarWidget_showPreviousYear},
    {sipName_showSelectedDate, meth_QCalendarWidget_showSelectedDate, METH_VARARGS, doc_QCalendarWidget_showSelectedDate},
    {sipName_showToday, meth_QCalendarWidget_showToday, METH_VARARGS, doc_QCalendarWidget_showToday},
    {sipName_sizeHint, meth_QCalendarWidget_sizeHint, METH_VARARGS, doc_QCalendarWidget_sizeHint},
    {sipName_updateCell, meth_QCalendarWidget_updateCell, METH_VARARGS, doc_QCalendarWidget_updateCell},
    {sipName_updateCells, meth_QCalendarWidget_updateCells, METH_VARARGS, doc_QCalendarWidget_updateCells},
    {sipName_verticalHeaderFormat, meth_QCalendarWidget_verticalHeaderFormat, METH_VARARGS, doc_QCalendarWidget_verticalHeaderFormat},
    {sipName_weekdayTextFormat, meth_QCalendarWidget_weekdayTextFormat, METH_VARARGS, doc_QCalendarWidget_weekdayTextFormat},
    {sipName_yearShown, meth_QCalendarWidget_yearShown, METH_VARARGS, doc_QCalendarWidget_yearShown}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QCalendarWidget[] = {
    {sipName_NoHorizontalHeader, static_cast<int>(::QCalendarWidget::NoHorizontalHeader)},
    {sipName_SingleLetterDayNames, static_cast<int>(::QCalendarWidget::SingleLetterDayNames)},
    {sipName_ShortDayNames, static_cast<int>(::QCalendarWidget::ShortDayNames)},
    {sipName_LongDayNames, static_cast<int>(::QCalendarWidget::LongDayNames)},
    {sipName_NoSelection, static_cast<int>(::QCalendarWidget::NoSelection)},
    {sipName_SingleSelection, static_cast<int>(::QCalendarWidget::SingleSelection)},
    {sipName_NoVerticalHeader, static_cast<int>(::QCalendarWidget::NoVerticalHeader)},
    {sipName_ISOWeekNumbers, static_cast<int>(::QCalendarWidget::ISOWeekNumbers)},
    {0, 0}
};

PyDoc_STRVAR(doc_QCalendarWidget, "\1QCalendarWidget(parent: QWidget|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QCalendarWidget[] = {
    {"selectionChanged()", "\1selectionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentPageChanged(int,int)", "\1currentPageChanged(self, year: int, month: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QDate)", "\1clicked(self, date: QDate|datetime.date)", SIP_NULLPTR, SIP_NULLPTR},
    {"activated(QDate)", "\1activated(self, date: QDate|datetime.date)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QCalendarWidget = {
    &::QCalendarWidget::staticMetaObject,
    signals_QCalendarWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QCalendarWidget = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCalendarWidget,
        SIP_NULLPTR,
        &plugin_QCalendarWidget,
    },
    {
        sipNameNr_QCalendarWidget,
        {0, 0, 1},
        52, methods_QCalendarWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QCalendarWidget, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCalendarWidget,
    -1,
    -1,
    supers_QCalendarWidget,
    SIP_NULLPTR,
    init_type_QCalendarWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCalendarWidget,
    SIP_NULLPTR,
    array_QCalendarWidget,
    SIP_NULLPTR,
    release_QCalendarWidget,
    cast_QCalendarWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCalendarWidget,
    sizeof (::QCalendarWidget),
};
